pub(crate) fn constrain_enum_value(
value: DynSolValue,
input: &Param,
fuzz_fixtures: &FuzzFixtures,
) -> DynSolValueExpand description
Constrains enum leaves in a decoded value to the range declared by its Solidity type.
pub(crate) fn constrain_enum_value(
value: DynSolValue,
input: &Param,
fuzz_fixtures: &FuzzFixtures,
) -> DynSolValueConstrains enum leaves in a decoded value to the range declared by its Solidity type.